/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*\

File: octvc1_module_gsm.c

Copyright (c) 2014 Octasic Inc. All rights reserved.

Description: Contain the wireshark module dissector related functions

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Release: Octasic Application Development Framework OCTADF-01.00.01-B497 (2014/01/09)

$Octasic_Revision: $

\*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/*****************************  INCLUDE FILES  *******************************/

#include <config.h>
#include <epan/packet.h>
#include "../../../include/oct_ws_macro.h"
#include "../include/module.h"
#include "../include/octvc1_common.h"

#include <gsm/octvc1_gsm_evt.h>


/****************************************************************************
	MODULE API ENUMERATION STRING VALUES
 ****************************************************************************/

const value_string  vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[] = 
 {
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT0, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT0" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT1, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT1" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT2, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT2" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT3, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT3" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT4, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT4" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT5, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TRX_ID_BIT5" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT0, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT0" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT1, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT1" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT2, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT2" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT3, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_BAND_BIT3" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_HOPPING, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_HOPPING" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT0, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT0" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT1, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT1" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT2, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT2" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT3, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT3" },
	{ cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT4, "cOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK_TSC_BIT4" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_SAPI_ENUM[] = 
 {
	{ cOCTVC1_GSM_SAPI_ENUM_IDLE, "cOCTVC1_GSM_SAPI_ENUM_IDLE" },
	{ cOCTVC1_GSM_SAPI_ENUM_FCCH, "cOCTVC1_GSM_SAPI_ENUM_FCCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_SCH, "cOCTVC1_GSM_SAPI_ENUM_SCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_SACCH, "cOCTVC1_GSM_SAPI_ENUM_SACCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_SDCCH, "cOCTVC1_GSM_SAPI_ENUM_SDCCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_BCCH, "cOCTVC1_GSM_SAPI_ENUM_BCCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PCH_AGCH, "cOCTVC1_GSM_SAPI_ENUM_PCH_AGCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_CBCH, "cOCTVC1_GSM_SAPI_ENUM_CBCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_RACH, "cOCTVC1_GSM_SAPI_ENUM_RACH" },
	{ cOCTVC1_GSM_SAPI_ENUM_TCHF, "cOCTVC1_GSM_SAPI_ENUM_TCHF" },
	{ cOCTVC1_GSM_SAPI_ENUM_FACCHF, "cOCTVC1_GSM_SAPI_ENUM_FACCHF" },
	{ cOCTVC1_GSM_SAPI_ENUM_TCHH, "cOCTVC1_GSM_SAPI_ENUM_TCHH" },
	{ cOCTVC1_GSM_SAPI_ENUM_FACCHH, "cOCTVC1_GSM_SAPI_ENUM_FACCHH" },
	{ cOCTVC1_GSM_SAPI_ENUM_NCH, "cOCTVC1_GSM_SAPI_ENUM_NCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PDTCH, "cOCTVC1_GSM_SAPI_ENUM_PDTCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PACCH, "cOCTVC1_GSM_SAPI_ENUM_PACCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PBCCH, "cOCTVC1_GSM_SAPI_ENUM_PBCCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PAGCH, "cOCTVC1_GSM_SAPI_ENUM_PAGCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PPCH, "cOCTVC1_GSM_SAPI_ENUM_PPCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PNCH, "cOCTVC1_GSM_SAPI_ENUM_PNCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PTCCH, "cOCTVC1_GSM_SAPI_ENUM_PTCCH" },
	{ cOCTVC1_GSM_SAPI_ENUM_PRACH, "cOCTVC1_GSM_SAPI_ENUM_PRACH" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_Channel_Type_ENUM[] = 
 {
	{ cOCTVC1_GSM_Channel_Type_ENUM_CCCH, "cOCTVC1_GSM_Channel_Type_ENUM_CCCH" },
	{ cOCTVC1_GSM_Channel_Type_ENUM_CCCH4, "cOCTVC1_GSM_Channel_Type_ENUM_CCCH4" },
	{ cOCTVC1_GSM_Channel_Type_ENUM_SDCCH, "cOCTVC1_GSM_Channel_Type_ENUM_SDCCH" },
	{ cOCTVC1_GSM_Channel_Type_ENUM_TCH_F, "cOCTVC1_GSM_Channel_Type_ENUM_TCH_F" },
	{ cOCTVC1_GSM_Channel_Type_ENUM_TCH_H, "cOCTVC1_GSM_Channel_Type_ENUM_TCH_H" },
	{ cOCTVC1_GSM_Channel_Type_ENUM_PDTCH, "cOCTVC1_GSM_Channel_Type_ENUM_PDTCH" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_CIPHERING_ENUM[] = 
 {
	{ cOCTVC1_GSM_CIPHERING_ENUM_A5_0, "cOCTVC1_GSM_CIPHERING_ENUM_A5_0" },
	{ cOCTVC1_GSM_CIPHERING_ENUM_A5_1, "cOCTVC1_GSM_CIPHERING_ENUM_A5_1" },
	{ cOCTVC1_GSM_CIPHERING_ENUM_A5_2, "cOCTVC1_GSM_CIPHERING_ENUM_A5_2" },
	{ cOCTVC1_GSM_CIPHERING_ENUM_A5_3, "cOCTVC1_GSM_CIPHERING_ENUM_A5_3" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_LOGICAL_CHANNEL_ENUM[] = 
 {
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_EMPTY, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_EMPTY" },
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_TCHF, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_TCHF" },
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_TCHH, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_TCHH" },
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_FCCH_SCH_BCCH_CCCH, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_FCCH_SCH_BCCH_CCCH" },
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_FCCH_SCH_BCCH_CCCH_SDCCH_SACCH, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_FCCH_SCH_BCCH_CCCH_SDCCH_SACCH" },
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_SDCCH_SACCH, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_SDCCH_SACCH" },
	{ cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_PDTCH_PACCH_PTCCH, "cOCTVC1_GSM_LOGICAL_CHANNEL_ENUM_PDTCH_PACCH_PTCCH" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_AMR_CODEC_ENUM[] = 
 {
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_4_75, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_4_75" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_5_15, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_5_15" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_5_90, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_5_90" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_6_70, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_6_70" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_7_40, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_7_40" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_7_95, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_7_95" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_10_2, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_10_2" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_12_2, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_12_2" },
	{ cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_Unset, "cOCTVC1_GSM_AMR_CODEC_ENUM_RATE_Unset" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_BURST_ENUM[] = 
 {
	{ cOCTVC1_GSM_BURST_ENUM_Synchronization, "cOCTVC1_GSM_BURST_ENUM_Synchronization" },
	{ cOCTVC1_GSM_BURST_ENUM_Normal, "cOCTVC1_GSM_BURST_ENUM_Normal" },
	{ cOCTVC1_GSM_BURST_ENUM_Dummy, "cOCTVC1_GSM_BURST_ENUM_Dummy" },
	{ cOCTVC1_GSM_BURST_ENUM_Normal_8PSK, "cOCTVC1_GSM_BURST_ENUM_Normal_8PSK" },
	{ cOCTVC1_GSM_BURST_ENUM_Access_TSC0, "cOCTVC1_GSM_BURST_ENUM_Access_TSC0" },
	{ cOCTVC1_GSM_BURST_ENUM_Access_TSC1, "cOCTVC1_GSM_BURST_ENUM_Access_TSC1" },
	{ cOCTVC1_GSM_BURST_ENUM_Access_TSC2, "cOCTVC1_GSM_BURST_ENUM_Access_TSC2" },
	{ cOCTVC1_GSM_BURST_ENUM_Frequency_Correction, "cOCTVC1_GSM_BURST_ENUM_Frequency_Correction" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_DIR_ENUM[] = 
 {
	{ cOCTVC1_GSM_DIR_ENUM_NO_PATH, "cOCTVC1_GSM_DIR_ENUM_NO_PATH" },
	{ cOCTVC1_GSM_DIR_ENUM_RX_MS_BTS, "cOCTVC1_GSM_DIR_ENUM_RX_MS_BTS" },
	{ cOCTVC1_GSM_DIR_ENUM_RX_BTS_MS, "cOCTVC1_GSM_DIR_ENUM_RX_BTS_MS" },
	{ cOCTVC1_GSM_DIR_ENUM_TX_BTS_MS, "cOCTVC1_GSM_DIR_ENUM_TX_BTS_MS" },
	{ cOCTVC1_GSM_DIR_ENUM_TX_MS_BTS, "cOCTVC1_GSM_DIR_ENUM_TX_MS_BTS" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_BAND_ENUM[] = 
 {
	{ cOCTVC1_GSM_BAND_ENUM_GSM450, "cOCTVC1_GSM_BAND_ENUM_GSM450" },
	{ cOCTVC1_GSM_BAND_ENUM_GSM850, "cOCTVC1_GSM_BAND_ENUM_GSM850" },
	{ cOCTVC1_GSM_BAND_ENUM_GSM900, "cOCTVC1_GSM_BAND_ENUM_GSM900" },
	{ cOCTVC1_GSM_BAND_ENUM_GSM1800, "cOCTVC1_GSM_BAND_ENUM_GSM1800" },
	{ cOCTVC1_GSM_BAND_ENUM_GSM1900, "cOCTVC1_GSM_BAND_ENUM_GSM1900" },
	{ cOCTVC1_GSM_BAND_ENUM_EGSM, "cOCTVC1_GSM_BAND_ENUM_EGSM" },
	{ cOCTVC1_GSM_BAND_ENUM_RGSM, "cOCTVC1_GSM_BAND_ENUM_RGSM" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_PROCESS_TYPE_ENUM[] = 
 {
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_INVALID, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_INVALID" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_CONTROL, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_CONTROL" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_TDM_DRIVER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_TDM_DRIVER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ROUTER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ROUTER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_SCHEDULER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_SCHEDULER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_VSPMGR, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_VSPMGR" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_AF_SRV, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_AF_SRV" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_CAMERA_DRIVER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_CAMERA_DRIVER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_WCDMA_SCHEDULER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_WCDMA_SCHEDULER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_L1C_APAPTATION_LAYER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_L1C_APAPTATION_LAYER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_RACH, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_RACH" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_MASTER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_RFI, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_RFI" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_SLAVE, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULIM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULOM_MASTER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULOM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULOM_SLAVE, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ULOM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLIM_MASTER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLIM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLIM_SLAVE, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLIM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLOM_MASTER, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLOM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLOM_SLAVE, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_DLOM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_RFI, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_RFI" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_ETH, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_ETH" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_HSDLOM, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_HSDLOM" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_HSDLIM, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_HSDLIM" },
	{ cOCTVC1_GSM_PROCESS_TYPE_ENUM_CTRL, "cOCTVC1_GSM_PROCESS_TYPE_ENUM_CTRL" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_EVT_MASK[] = 
 {
	{ cOCTVC1_GSM_EVT_MASK_ERROR, "cOCTVC1_GSM_EVT_MASK_ERROR" },
	{ cOCTVC1_GSM_EVT_MASK_TRACE_REQUEST, "cOCTVC1_GSM_EVT_MASK_TRACE_REQUEST" },
	{ cOCTVC1_GSM_EVT_MASK_TRACE_RESPONSE, "cOCTVC1_GSM_EVT_MASK_TRACE_RESPONSE" },
	{ cOCTVC1_GSM_EVT_MASK_MESSAGE, "cOCTVC1_GSM_EVT_MASK_MESSAGE" },
	{ cOCTVC1_GSM_EVT_MASK_CHECKPOINT, "cOCTVC1_GSM_EVT_MASK_CHECKPOINT" },
	{ cOCTVC1_GSM_EVT_MASK_ALL, "cOCTVC1_GSM_EVT_MASK_ALL" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM[] = 
 {
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_INVALID, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_INVALID" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_WCDMA_SCHEDULER, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_WCDMA_SCHEDULER" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_L1C_APAPTATION_LAYER, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_L1C_APAPTATION_LAYER" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_RACH, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_RACH" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_MASTER, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_RFI, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_RFI" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_SLAVE, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULIM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULOM_MASTER, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULOM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULOM_SLAVE, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ULOM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLIM_MASTER, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLIM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLIM_SLAVE, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLIM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLOM_MASTER, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLOM_MASTER" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLOM_SLAVE, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLOM_SLAVE" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLIM_RFI, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_DLIM_RFI" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ETH, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_ETH" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_HSDLOM, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_HSDLOM" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_HSDLIM, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_HSDLIM" },
	{ cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_CTRL, "cOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM_CTRL" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_CHECKPOINT_TYPE_ENUM[] = 
 {
	{ cOCTVC1_GSM_CHECKPOINT_TYPE_ENUM_START, "cOCTVC1_GSM_CHECKPOINT_TYPE_ENUM_START" },
	{ cOCTVC1_GSM_CHECKPOINT_TYPE_ENUM_END, "cOCTVC1_GSM_CHECKPOINT_TYPE_ENUM_END" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_CHECKPOINT_STATE_ENUM[] = 
 {
	{ cOCTVC1_GSM_CHECKPOINT_STATE_ENUM_OK, "cOCTVC1_GSM_CHECKPOINT_STATE_ENUM_OK" },
	{ cOCTVC1_GSM_CHECKPOINT_STATE_ENUM_PROCESSING_ERROR, "cOCTVC1_GSM_CHECKPOINT_STATE_ENUM_PROCESSING_ERROR" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_MSG_SEVERITY_ENUM[] = 
 {
	{ cOCTVC1_GSM_MSG_SEVERITY_ENUM_INFO, "cOCTVC1_GSM_MSG_SEVERITY_ENUM_INFO" },
	{ cOCTVC1_GSM_MSG_SEVERITY_ENUM_WARNING, "cOCTVC1_GSM_MSG_SEVERITY_ENUM_WARNING" },
	{ cOCTVC1_GSM_MSG_SEVERITY_ENUM_ERROR, "cOCTVC1_GSM_MSG_SEVERITY_ENUM_ERROR" },
	{ cOCTVC1_GSM_MSG_SEVERITY_ENUM_FATAL, "cOCTVC1_GSM_MSG_SEVERITY_ENUM_FATAL" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_TRACING_TYPE_ENUM[] = 
 {
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_DLOM_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_DLOM_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_DLOM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_DLOM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_DLIM_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_DLIM_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_DLIM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_DLIM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULOM_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULOM_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULOM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULOM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RACH_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RACH_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RACHM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RACHM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RACHP_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_ULIM_RACHP_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_SCHEDPARAMS, "cOCTVC1_GSM_TRACING_TYPE_ENUM_SCHEDPARAMS" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLOM_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLOM_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLOM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLOM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLIM_REQUEST, "cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLIM_REQUEST" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLIM_RESPONSE, "cOCTVC1_GSM_TRACING_TYPE_ENUM_HSDLIM_RESPONSE" },
	{ cOCTVC1_GSM_TRACING_TYPE_ENUM_NOTDEFINED, "cOCTVC1_GSM_TRACING_TYPE_ENUM_NOTDEFINED" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_ERR_ENUM[] = 
 {
	{ cOCTVC1_GSM_ERR_ENUM_GENERIC_INPUT_FIFO_OVERFLOW, "cOCTVC1_GSM_ERR_ENUM_GENERIC_INPUT_FIFO_OVERFLOW" },
	{ cOCTVC1_GSM_ERR_ENUM_GENERIC_INVALID_INPUT_PKT_FORMAT, "cOCTVC1_GSM_ERR_ENUM_GENERIC_INVALID_INPUT_PKT_FORMAT" },
	{ cOCTVC1_GSM_ERR_ENUM_GENERIC_OUTPUT_FIFO_FULL, "cOCTVC1_GSM_ERR_ENUM_GENERIC_OUTPUT_FIFO_FULL" },
	{ cOCTVC1_GSM_ERR_ENUM_GENERIC_INPUT_FIFO_EMPTY, "cOCTVC1_GSM_ERR_ENUM_GENERIC_INPUT_FIFO_EMPTY" },
	{ cOCTVC1_GSM_ERR_ENUM_SYSTEM_BOOT_ERROR, "cOCTVC1_GSM_ERR_ENUM_SYSTEM_BOOT_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_SYSTEM_EXIT_ERROR, "cOCTVC1_GSM_ERR_ENUM_SYSTEM_EXIT_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_DMA_INIT_ERROR, "cOCTVC1_GSM_ERR_ENUM_DMA_INIT_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_DMA_MODE_ERROR, "cOCTVC1_GSM_ERR_ENUM_DMA_MODE_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_DMA_WRITE_ERROR, "cOCTVC1_GSM_ERR_ENUM_DMA_WRITE_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_DMA_READ_ERROR, "cOCTVC1_GSM_ERR_ENUM_DMA_READ_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_DOWNLINK_INNER_MODEM_INTERNAL_ERROR, "cOCTVC1_GSM_ERR_ENUM_DOWNLINK_INNER_MODEM_INTERNAL_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_DOWNLINK_OUTER_MODEM_INTERNAL_ERROR, "cOCTVC1_GSM_ERR_ENUM_DOWNLINK_OUTER_MODEM_INTERNAL_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_UPLINK_INNER_MODEM_INTERNAL_ERROR, "cOCTVC1_GSM_ERR_ENUM_UPLINK_INNER_MODEM_INTERNAL_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_UPLINK_OUTER_MODEM_INTERNAL_ERROR, "cOCTVC1_GSM_ERR_ENUM_UPLINK_OUTER_MODEM_INTERNAL_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_RF_INTERFACE_INTERNAL_ERROR, "cOCTVC1_GSM_ERR_ENUM_RF_INTERFACE_INTERNAL_ERROR" },
	{ cOCTVC1_GSM_ERR_ENUM_LAST, "cOCTVC1_GSM_ERR_ENUM_LAST" },
	{ 0,		NULL }
 };

const value_string  vals_tOCTVC1_GSM_2G_MSG_ENUM[] = 
 {
	{ cOCTVC1_GSM_2G_MSG_ENUM_INTERNAL_ERROR, "cOCTVC1_GSM_2G_MSG_ENUM_INTERNAL_ERROR" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_GENERIC_HELLO_WORLD, "cOCTVC1_GSM_2G_MSG_ENUM_GENERIC_HELLO_WORLD" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SPECIFIC_SUBJECT_HELLO_WORLD, "cOCTVC1_GSM_2G_MSG_ENUM_SPECIFIC_SUBJECT_HELLO_WORLD" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_ULIM_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_ULIM_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_ULOM_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_ULOM_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_DLIM_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_DLIM_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_DLOM_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_DLOM_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_L1C_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_L1C_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_RACH_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_RACH_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_DL_RFI_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_DL_RFI_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_UL_RFI_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_UL_RFI_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_HSDLOM_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_HSDLOM_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_HSDLIM_READY, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_HSDLIM_READY" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_MODEM_SETUP_COMPLETED, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_MODEM_SETUP_COMPLETED" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_CELL_SETUP_COMPLETED, "cOCTVC1_GSM_2G_MSG_ENUM_SYSTEM_CELL_SETUP_COMPLETED" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_ULIM_RACH_DETECT, "cOCTVC1_GSM_2G_MSG_ENUM_ULIM_RACH_DETECT" },
	{ cOCTVC1_GSM_2G_MSG_ENUM_LAST, "cOCTVC1_GSM_2G_MSG_ENUM_LAST" },
	{ 0,		NULL }
 };

/****************************************************************************
	COMMON Registered 
 ****************************************************************************/

int ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[4];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_tSUBCHANNEL_STATUS;

void  register_tOCTVC1_GSM_tSUBCHANNEL_STATUS(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[0],
			{ "usActiveUplinkSAPIMapMSW", "octvc1.gsm.tsubchannel_status.usactiveuplinksapimapmsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usActiveUplinkSAPIMapMSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[1],
			{ "usActiveUplinkSAPIMapLSW", "octvc1.gsm.tsubchannel_status.usactiveuplinksapimaplsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usActiveUplinkSAPIMapLSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[2],
			{ "usActiveDownlinkSAPIMapMSW", "octvc1.gsm.tsubchannel_status.usactivedownlinksapimapmsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usActiveDownlinkSAPIMapMSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[3],
			{ "usActiveDownlinkSAPIMapLSW", "octvc1.gsm.tsubchannel_status.usactivedownlinksapimaplsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usActiveDownlinkSAPIMapLSW",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_tSUBCHANNEL_STATUS.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_tMEASUREMENT_INFO;

void  register_tOCTVC1_GSM_tMEASUREMENT_INFO(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[0],
			{ "sRSSI", "octvc1.gsm.tmeasurement_info.srssi",
			FT_INT16,BASE_DEC, NULL, 0x0,
			"sRSSI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[1],
			{ "sSNR", "octvc1.gsm.tmeasurement_info.ssnr",
			FT_INT16,BASE_DEC, NULL, 0x0,
			"sSNR",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[2],
			{ "sBurstTiming", "octvc1.gsm.tmeasurement_info.sbursttiming",
			FT_INT16,BASE_DEC, NULL, 0x0,
			"sBurstTiming",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[3],
			{ "usBERCount", "octvc1.gsm.tmeasurement_info.usbercount",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usBERCount",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[4],
			{ "usBERTOtalBitCOunt", "octvc1.gsm.tmeasurement_info.usbertotalbitcount",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usBERTOtalBitCOunt",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_tMEASUREMENT_INFO.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_TIMESLOT_STATUS[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_TIMESLOT_STATUS;

void  register_tOCTVC1_GSM_TIMESLOT_STATUS(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_TIMESLOT_STATUS[0],
			{ "byChannelType", "octvc1.gsm.timeslot_status.bychanneltype",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byChannelType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_TIMESLOT_STATUS[1],
			{ "bySubchannelCount", "octvc1.gsm.timeslot_status.bysubchannelcount",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelCount",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_TIMESLOT_STATUS.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

/****************************************************************************
	Event Registered 
 ****************************************************************************/

int ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.module.time_indication.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[1],
			{ "byu5Pad_u3TN", "octvc1.gsm.module.time_indication.byu5pad_u3tn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[2],
			{ "usFrameNumberMSW", "octvc1.gsm.module.time_indication.usframenumbermsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberMSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[3],
			{ "usFrameNumberLSW", "octvc1.gsm.module.time_indication.usframenumberlsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberLSW",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[10];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.module.data_indication.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[1],
			{ "byu5SAPI_u3Dir", "octvc1.gsm.module.data_indication.byu5sapi_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5SAPI_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[2],
			{ "bySubchannelNum", "octvc1.gsm.module.data_indication.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[3],
			{ "byu5Pad_u3TN", "octvc1.gsm.module.data_indication.byu5pad_u3tn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[4],
			{ "usFrameNumberMSW", "octvc1.gsm.module.data_indication.usframenumbermsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberMSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[5],
			{ "usFrameNumberLSW", "octvc1.gsm.module.data_indication.usframenumberlsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberLSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[6],
			{ "tMeasurementInfo", "octvc1.gsm.module.data_indication.tmeasurementinfo",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"tMeasurementInfo",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[7],
			{ "usDataFrameLength", "octvc1.gsm.module.data_indication.usdataframelength",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usDataFrameLength",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[8],
			{ "ausDataFrameContents", "octvc1.gsm.module.data_indication.ausdataframecontents",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"ausDataFrameContents",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.module.trx_radio_ready.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[7];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.module.ready_to_send_indication.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[1],
			{ "byu3TN_u5SAPI", "octvc1.gsm.module.ready_to_send_indication.byu3tn_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu3TN_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[2],
			{ "bySubchannelNum", "octvc1.gsm.module.ready_to_send_indication.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[3],
			{ "byPad", "octvc1.gsm.module.ready_to_send_indication.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[4],
			{ "usFrameNumberMSW", "octvc1.gsm.module.ready_to_send_indication.usframenumbermsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberMSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[5],
			{ "usFrameNumberLSW", "octvc1.gsm.module.ready_to_send_indication.usframenumberlsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberLSW",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[10];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.module.rach_indication.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[1],
			{ "byuu3TN_u5SAPI", "octvc1.gsm.module.rach_indication.byuu3tn_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byuu3TN_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[2],
			{ "bySubchannelNum", "octvc1.gsm.module.rach_indication.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[3],
			{ "byBurstType", "octvc1.gsm.module.rach_indication.bybursttype",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byBurstType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[4],
			{ "usFrameNumberMSW", "octvc1.gsm.module.rach_indication.usframenumbermsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberMSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[5],
			{ "usFrameNumberLSW", "octvc1.gsm.module.rach_indication.usframenumberlsw",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberLSW",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[6],
			{ "tMeasurementInfo", "octvc1.gsm.module.rach_indication.tmeasurementinfo",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"tMeasurementInfo",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[7],
			{ "usMessageLength", "octvc1.gsm.module.rach_indication.usmessagelength",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usMessageLength",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[8],
			{ "ausMessageContents", "octvc1.gsm.module.rach_indication.ausmessagecontents",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"ausMessageContents",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_ERROR_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.module.error.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT[1],
			{ "ulErrorCode", "octvc1.gsm.module.error.ulerrorcode",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_ERR_ENUM), 0x0,
			"ulErrorCode",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_ERROR_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT[4];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.module.message.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT[1],
			{ "ulMessageCode", "octvc1.gsm.module.message.ulmessagecode",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_2G_MSG_ENUM), 0x0,
			"ulMessageCode",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT[2],
			{ "ulSeverityLevel", "octvc1.gsm.module.message.ulseveritylevel",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_MSG_SEVERITY_ENUM), 0x0,
			"ulSeverityLevel",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[9];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.module.checkpoint.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[1],
			{ "ulCoreId", "octvc1.gsm.module.checkpoint.ulcoreid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulCoreId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[2],
			{ "ulFrameIndex", "octvc1.gsm.module.checkpoint.ulframeindex",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulFrameIndex",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[3],
			{ "ulSlotIndex", "octvc1.gsm.module.checkpoint.ulslotindex",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulSlotIndex",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[4],
			{ "ulCheckPointType", "octvc1.gsm.module.checkpoint.ulcheckpointtype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_CHECKPOINT_TYPE_ENUM), 0x0,
			"ulCheckPointType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[5],
			{ "ulProcessUnitType", "octvc1.gsm.module.checkpoint.ulprocessunittype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM), 0x0,
			"ulProcessUnitType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[6],
			{ "ulState", "octvc1.gsm.module.checkpoint.ulstate",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_CHECKPOINT_STATE_ENUM), 0x0,
			"ulState",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[7],
			{ "aulReserved", "octvc1.gsm.module.checkpoint.aulreserved",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"aulReserved",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[8];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_TRACING_EVT;

void  register_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.module.tracing.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[1],
			{ "ulCoreId", "octvc1.gsm.module.tracing.ulcoreid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulCoreId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[2],
			{ "ulTraceType", "octvc1.gsm.module.tracing.ultracetype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_TRACING_TYPE_ENUM), 0x0,
			"ulTraceType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[3],
			{ "ulLastTracePacket", "octvc1.gsm.module.tracing.ullasttracepacket",
			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
			"ulLastTracePacket",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[4],
			{ "ulTraceIndex", "octvc1.gsm.module.tracing.ultraceindex",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulTraceIndex",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[5],
			{ "ulPayloadSizeBytes", "octvc1.gsm.module.tracing.ulpayloadsizebytes",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulPayloadSizeBytes",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[6],
			{ "abyUnparsedPayload", "octvc1.gsm.module.tracing.abyunparsedpayload",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"abyUnparsedPayload",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_TRACING_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.error.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT[1],
			{ "ulErrorCode", "octvc1.gsm.process_unit.error.ulerrorcode",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_ERR_ENUM), 0x0,
			"ulErrorCode",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT[4];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.message.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT[1],
			{ "ulMessageCode", "octvc1.gsm.process_unit.message.ulmessagecode",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_2G_MSG_ENUM), 0x0,
			"ulMessageCode",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT[2],
			{ "ulSeverityLevel", "octvc1.gsm.process_unit.message.ulseveritylevel",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_MSG_SEVERITY_ENUM), 0x0,
			"ulSeverityLevel",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[9];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.checkpoint.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[1],
			{ "ulCoreId", "octvc1.gsm.process_unit.checkpoint.ulcoreid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulCoreId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[2],
			{ "ulFrameIndex", "octvc1.gsm.process_unit.checkpoint.ulframeindex",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulFrameIndex",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[3],
			{ "ulSlotIndex", "octvc1.gsm.process_unit.checkpoint.ulslotindex",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulSlotIndex",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[4],
			{ "ulCheckPointType", "octvc1.gsm.process_unit.checkpoint.ulcheckpointtype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_CHECKPOINT_TYPE_ENUM), 0x0,
			"ulCheckPointType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[5],
			{ "ulProcessUnitType", "octvc1.gsm.process_unit.checkpoint.ulprocessunittype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_PROCESS_UNIT_TYPE_ENUM), 0x0,
			"ulProcessUnitType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[6],
			{ "ulState", "octvc1.gsm.process_unit.checkpoint.ulstate",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_CHECKPOINT_STATE_ENUM), 0x0,
			"ulState",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[7],
			{ "aulReserved", "octvc1.gsm.process_unit.checkpoint.aulreserved",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"aulReserved",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.tracing.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[1],
			{ "ulCoreId", "octvc1.gsm.process_unit.tracing.ulcoreid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulCoreId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[2],
			{ "ulTraceType", "octvc1.gsm.process_unit.tracing.ultracetype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_TRACING_TYPE_ENUM), 0x0,
			"ulTraceType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[3],
			{ "ulPayloadSizeBytes", "octvc1.gsm.process_unit.tracing.ulpayloadsizebytes",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulPayloadSizeBytes",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[4],
			{ "abyUnparsedPayload", "octvc1.gsm.process_unit.tracing.abyunparsedpayload",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"abyUnparsedPayload",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT;

void  register_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT[0],
			{ "usTodo", "octvc1.gsm.test.etsi.test_report.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

/****************************************************************************
	CMD/RSP Registered 
 ****************************************************************************/

int ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD;

void  register_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD[0],
			{ "aPadding", "octvc1.gsm.module.hardware.info.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP;

void  register_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP[0],
			{ "szHardwareInfo", "octvc1.gsm.module.hardware.info.szhardwareinfo",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"szHardwareInfo",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP[1],
			{ "aPadding", "octvc1.gsm.module.hardware.info.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD;

void  register_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[0],
			{ "ulEventMask", "octvc1.gsm.module.evt.modify.uleventmask",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ulEventMask",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[1],
			{ "ulUserEventId", "octvc1.gsm.module.evt.modify.ulusereventid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulUserEventId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[2],
			{ "hEventDestObj", "octvc1.gsm.module.evt.modify.heventdestobj",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hEventDestObj",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[3],
			{ "ulEventDestObjPort", "octvc1.gsm.module.evt.modify.uleventdestobjport",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulEventDestObjPort",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[4],
			{ "ulEventDestObjFifoId", "octvc1.gsm.module.evt.modify.uleventdestobjfifoid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulEventDestObjFifoId",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP;

void  register_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[0],
			{ "ulEventMask", "octvc1.gsm.module.evt.info.uleventmask",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ulEventMask",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[1],
			{ "ulUserEventId", "octvc1.gsm.module.evt.info.ulusereventid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulUserEventId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[2],
			{ "hEventDestObj", "octvc1.gsm.module.evt.info.heventdestobj",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hEventDestObj",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[3],
			{ "ulEventDestObjPort", "octvc1.gsm.module.evt.info.uleventdestobjport",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulEventDestObjPort",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[4],
			{ "ulEventDestObjFifoId", "octvc1.gsm.module.evt.info.uleventdestobjfifoid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulEventDestObjFifoId",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_MODULE_INFO_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_MODULE_INFO_RSP;

void  register_tOCTVC1_GSM_MSG_MODULE_INFO_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_MODULE_INFO_RSP[0],
			{ "ulDeviceType", "octvc1.gsm.module.info.uldevicetype",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulDeviceType",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_MODULE_INFO_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.evt.modify.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[1],
			{ "ulUserEventId", "octvc1.gsm.process_unit.evt.modify.ulusereventid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulUserEventId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[2],
			{ "ulEventMask", "octvc1.gsm.process_unit.evt.modify.uleventmask",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ulEventMask",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[3],
			{ "ulDebugFwdEventMask", "octvc1.gsm.process_unit.evt.modify.uldebugfwdeventmask",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ulDebugFwdEventMask",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.evt.modify.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD[0],
			{ "hProcessUnit", "octvc1.gsm.process_unit.evt.info.hprocessunit",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hProcessUnit",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[0],
			{ "ulEventMask", "octvc1.gsm.process_unit.evt.info.uleventmask",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ulEventMask",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[1],
			{ "ulUserEventId", "octvc1.gsm.process_unit.evt.info.ulusereventid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulUserEventId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[2],
			{ "hEventDestObj", "octvc1.gsm.process_unit.evt.info.heventdestobj",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"hEventDestObj",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[3],
			{ "ulEventDestObjPort", "octvc1.gsm.process_unit.evt.info.uleventdestobjport",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulEventDestObjPort",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[4],
			{ "ulEventDestObjFifoId", "octvc1.gsm.process_unit.evt.info.uleventdestobjfifoid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulEventDestObjFifoId",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD[0],
			{ "ObjectCursor", "octvc1.gsm.process_unit.list.objectcursor",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectCursor",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP[0],
			{ "ObjectCursor", "octvc1.gsm.process_unit.list.objectcursor",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectCursor",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP[1],
			{ "ObjectList", "octvc1.gsm.process_unit.list.objectlist",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectList",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD[0],
			{ "ObjectGet", "octvc1.gsm.process_unit.info.objectget",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectGet",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[0],
			{ "ObjectGet", "octvc1.gsm.process_unit.info.objectget",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectGet",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[1],
			{ "ulProcessType", "octvc1.gsm.process_unit.info.ulprocesstype",
			FT_UINT32,BASE_HEX, VALS(vals_tOCTVC1_GSM_PROCESS_TYPE_ENUM), 0x0,
			"ulProcessType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[2],
			{ "ulInstance", "octvc1.gsm.process_unit.info.ulinstance",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulInstance",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[3],
			{ "ulMasterCore", "octvc1.gsm.process_unit.info.ulmastercore",
			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
			"ulMasterCore",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[4],
			{ "ulCoreId", "octvc1.gsm.process_unit.info.ulcoreid",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulCoreId",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD[0],
			{ "ObjectGet", "octvc1.gsm.process_unit.stats.objectget",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectGet",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD[1],
			{ "ulResetStatsFlag", "octvc1.gsm.process_unit.stats.ulresetstatsflag",
			FT_BOOLEAN, BASE_NONE, NULL, 0x0,
			"ulResetStatsFlag",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP;

void  register_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP[0],
			{ "ObjectGet", "octvc1.gsm.process_unit.stats.objectget",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"ObjectGet",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP[1],
			{ "ulLastFrameIndex", "octvc1.gsm.process_unit.stats.ullastframeindex",
			FT_UINT32,BASE_HEX, NULL, 0x0,
			"ulLastFrameIndex",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[8];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.physical_channel.empty_frame.request.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[1],
			{ "byu3TN_u5SAPI", "octvc1.gsm.physical_channel.empty_frame.request.byu3tn_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu3TN_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[2],
			{ "bySubchannelNum", "octvc1.gsm.physical_channel.empty_frame.request.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[3],
			{ "byPad", "octvc1.gsm.physical_channel.empty_frame.request.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[4],
			{ "usFrameNumberMsb", "octvc1.gsm.physical_channel.empty_frame.request.usframenumbermsb",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberMsb",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[5],
			{ "usFrameNumberLsb", "octvc1.gsm.physical_channel.empty_frame.request.usframenumberlsb",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberLsb",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[6],
			{ "aPadding", "octvc1.gsm.physical_channel.empty_frame.request.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP[0],
			{ "usTodo", "octvc1.gsm.physical_channel.empty_frame.request.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[9];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[0],
			{ "byU2Pad_u6TRXId", "octvc1.gsm.physical_channel.data.request.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byU2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[1],
			{ "byU3TN_u5SAPI", "octvc1.gsm.physical_channel.data.request.byu3tn_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byU3TN_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[2],
			{ "bySubchannelNum", "octvc1.gsm.physical_channel.data.request.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[3],
			{ "byPad", "octvc1.gsm.physical_channel.data.request.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[4],
			{ "usFrameNumberMSB", "octvc1.gsm.physical_channel.data.request.usframenumbermsb",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberMSB",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[5],
			{ "usFrameNumberLSB", "octvc1.gsm.physical_channel.data.request.usframenumberlsb",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usFrameNumberLSB",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[6],
			{ "usDataLength", "octvc1.gsm.physical_channel.data.request.usdatalength",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usDataLength",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[7],
			{ "ausDataContents", "octvc1.gsm.physical_channel.data.request.ausdatacontents",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"ausDataContents",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP[0],
			{ "usTodo", "octvc1.gsm.physical_channel.data.request.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[9];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.physical_channel.ciphering.configure.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[1],
			{ "byu2Pad_u3TN_u3Dir", "octvc1.gsm.physical_channel.ciphering.configure.byu2pad_u3tn_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TN_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[2],
			{ "bySubchannelNum", "octvc1.gsm.physical_channel.ciphering.configure.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[3],
			{ "byuCipherId", "octvc1.gsm.physical_channel.ciphering.configure.byucipherid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byuCipherId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[4],
			{ "usKC0", "octvc1.gsm.physical_channel.ciphering.configure.uskc0",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usKC0",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[5],
			{ "usKC1", "octvc1.gsm.physical_channel.ciphering.configure.uskc1",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usKC1",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[6],
			{ "usKC2", "octvc1.gsm.physical_channel.ciphering.configure.uskc2",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usKC2",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[7],
			{ "usKC3", "octvc1.gsm.physical_channel.ciphering.configure.uskc3",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usKC3",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[7];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.physical_channel.ciphering.configure.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[1],
			{ "byu2Pad_u3TN_u3Dir", "octvc1.gsm.physical_channel.ciphering.configure.byu2pad_u3tn_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TN_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[2],
			{ "bySubchannelNum", "octvc1.gsm.physical_channel.ciphering.configure.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[3],
			{ "byPad", "octvc1.gsm.physical_channel.ciphering.configure.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[4],
			{ "usStatus", "octvc1.gsm.physical_channel.ciphering.configure.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[5],
			{ "aPadding", "octvc1.gsm.physical_channel.ciphering.configure.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[0],
			{ "byu2Pad_u6TrxId", "octvc1.gsm.physical_channel.connect.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TrxId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[1],
			{ "byu5Pad_u3TimeslotNumber", "octvc1.gsm.physical_channel.connect.byu5pad_u3timeslotnumber",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TimeslotNumber",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[2],
			{ "byChannelType", "octvc1.gsm.physical_channel.connect.bychanneltype",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byChannelType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[3],
			{ "byPayloadType", "octvc1.gsm.physical_channel.connect.bypayloadtype",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPayloadType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[4],
			{ "aPadding", "octvc1.gsm.physical_channel.connect.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.physical_channel.connect.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[1],
			{ "byu5Pad_u3TN", "octvc1.gsm.physical_channel.connect.byu5pad_u3tn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[2],
			{ "usStatus", "octvc1.gsm.physical_channel.connect.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[3],
			{ "aPadding", "octvc1.gsm.physical_channel.connect.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[4];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[0],
			{ "byu2Pad_u6TrxId", "octvc1.gsm.physical_channel.disconnect.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TrxId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[1],
			{ "byu5Pad_u3TimeslotNumber", "octvc1.gsm.physical_channel.disconnect.byu5pad_u3timeslotnumber",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TimeslotNumber",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[2],
			{ "aPadding", "octvc1.gsm.physical_channel.disconnect.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.physical_channel.disconnect.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[1],
			{ "byu5Pad_u3TN", "octvc1.gsm.physical_channel.disconnect.byu5pad_u3tn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[2],
			{ "usStatus", "octvc1.gsm.physical_channel.disconnect.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[3],
			{ "aPadding", "octvc1.gsm.physical_channel.disconnect.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD[0],
			{ "aPadding", "octvc1.gsm.physical_channel.reset.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP;

void  register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP[0],
			{ "usStatus", "octvc1.gsm.physical_channel.reset.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP[1],
			{ "aPadding", "octvc1.gsm.physical_channel.reset.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[12];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD;

void  register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.logical_channel.activate.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[1],
			{ "byu2Pad_u3TN_u3Dir", "octvc1.gsm.logical_channel.activate.byu2pad_u3tn_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TN_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[2],
			{ "bySubchannelNum", "octvc1.gsm.logical_channel.activate.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[3],
			{ "byu3Pad_u5SAPI", "octvc1.gsm.logical_channel.activate.byu3pad_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu3Pad_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[4],
			{ "byTimingAdvance", "octvc1.gsm.logical_channel.activate.bytimingadvance",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byTimingAdvance",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[5],
			{ "byPad", "octvc1.gsm.logical_channel.activate.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[6],
			{ "byBSIC", "octvc1.gsm.logical_channel.activate.bybsic",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byBSIC",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[7],
			{ "byu1CMIPhase_u7InitRate", "octvc1.gsm.logical_channel.activate.byu1cmiphase_u7initrate",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu1CMIPhase_u7InitRate",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[8],
			{ "byu4Rate1_u4Rate2", "octvc1.gsm.logical_channel.activate.byu4rate1_u4rate2",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu4Rate1_u4Rate2",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[9],
			{ "byu4Rate3_u4Rate4", "octvc1.gsm.logical_channel.activate.byu4rate3_u4rate4",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu4Rate3_u4Rate4",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[10],
			{ "aPadding", "octvc1.gsm.logical_channel.activate.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[7];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP;

void  register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[0],
			{ "byu2Pad_u3TRXId", "octvc1.gsm.logical_channel.activate.byu2pad_u3trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[1],
			{ "byu2Pad_u3TN_u3Dir", "octvc1.gsm.logical_channel.activate.byu2pad_u3tn_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TN_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[2],
			{ "bySubchannelNum", "octvc1.gsm.logical_channel.activate.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[3],
			{ "byu3Pad_u5SAPI", "octvc1.gsm.logical_channel.activate.byu3pad_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu3Pad_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[4],
			{ "usStatus", "octvc1.gsm.logical_channel.activate.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[5],
			{ "aPadding", "octvc1.gsm.logical_channel.activate.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD;

void  register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.logical_channel.deactivate.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[1],
			{ "byu2Pad_u3TN_u3Dir", "octvc1.gsm.logical_channel.deactivate.byu2pad_u3tn_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TN_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[2],
			{ "bySubchannelNum", "octvc1.gsm.logical_channel.deactivate.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[3],
			{ "byu3Pad_u5SAPI", "octvc1.gsm.logical_channel.deactivate.byu3pad_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu3Pad_u5SAPI",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[7];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP;

void  register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[0],
			{ "byu2Pad_u3TRXId", "octvc1.gsm.logical_channel.deactivate.byu2pad_u3trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[1],
			{ "byu2Pad_u3TN_u3Dir", "octvc1.gsm.logical_channel.deactivate.byu2pad_u3tn_u3dir",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u3TN_u3Dir",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[2],
			{ "bySubchannelNum", "octvc1.gsm.logical_channel.deactivate.bysubchannelnum",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelNum",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[3],
			{ "byu3Pad_u5SAPI", "octvc1.gsm.logical_channel.deactivate.byu3pad_u5sapi",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu3Pad_u5SAPI",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[4],
			{ "usStatus", "octvc1.gsm.logical_channel.deactivate.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[5],
			{ "aPadding", "octvc1.gsm.logical_channel.deactivate.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD;

void  register_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD[0],
			{ "usu2Pad_u6TRXId_u5Pad_u3TN", "octvc1.gsm.trx.timeslot.status.usu2pad_u6trxid_u5pad_u3tn",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usu2Pad_u6TRXId_u5Pad_u3TN",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[6];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP;

void  register_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[0],
			{ "usu2Pad_u6TRXId_u5Pad_u3TN", "octvc1.gsm.trx.timeslot.status.usu2pad_u6trxid_u5pad_u3tn",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usu2Pad_u6TRXId_u5Pad_u3TN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[1],
			{ "byChannelType", "octvc1.gsm.trx.timeslot.status.bychanneltype",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byChannelType",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[2],
			{ "bySubchannelCount", "octvc1.gsm.trx.timeslot.status.bysubchannelcount",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"bySubchannelCount",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[3],
			{ "atSubchannnelStatus", "octvc1.gsm.trx.timeslot.status.atsubchannnelstatus",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"atSubchannnelStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[4],
			{ "aPadding", "octvc1.gsm.trx.timeslot.status.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD;

void  register_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.trx.timeslot_measurement_report.request.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD[1],
			{ "byu5Pad_u3TN", "octvc1.gsm.trx.timeslot_measurement_report.request.byu5pad_u3tn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TN",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP;

void  register_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.trx.timeslot_measurement_report.request.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[1],
			{ "byu5Pad_u3TN", "octvc1.gsm.trx.timeslot_measurement_report.request.byu5pad_u3tn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu5Pad_u3TN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[2],
			{ "tMeasurementInfo", "octvc1.gsm.trx.timeslot_measurement_report.request.tmeasurementinfo",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"tMeasurementInfo",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[3],
			{ "aPadding", "octvc1.gsm.trx.timeslot_measurement_report.request.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_RESET_CMD[3];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_RESET_CMD;

void  register_tOCTVC1_GSM_MSG_TRX_RESET_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_RESET_CMD[0],
			{ "usu2Pad_u6TRXId_u8Pad", "octvc1.gsm.trx.reset.usu2pad_u6trxid_u8pad",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usu2Pad_u6TRXId_u8Pad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_RESET_CMD[1],
			{ "aPadding", "octvc1.gsm.trx.reset.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_RESET_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_RESET_RSP;

void  register_tOCTVC1_GSM_MSG_TRX_RESET_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.trx.reset.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[1],
			{ "byPad", "octvc1.gsm.trx.reset.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[2],
			{ "usStatus", "octvc1.gsm.trx.reset.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[3],
			{ "aPadding", "octvc1.gsm.trx.reset.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_RESET_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_STATUS_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_STATUS_CMD;

void  register_tOCTVC1_GSM_MSG_TRX_STATUS_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_CMD[0],
			{ "usu2Pad_u6TRXId_u8Pad", "octvc1.gsm.trx.status.usu2pad_u6trxid_u8pad",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usu2Pad_u6TRXId_u8Pad",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_STATUS_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[5];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_STATUS_RSP;

void  register_tOCTVC1_GSM_MSG_TRX_STATUS_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[0],
			{ "byu2Pad_u6TRXId", "octvc1.gsm.trx.status.byu2pad_u6trxid",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byu2Pad_u6TRXId",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[1],
			{ "byPad", "octvc1.gsm.trx.status.bypad",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"byPad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[2],
			{ "atStatus", "octvc1.gsm.trx.status.atstatus",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"atStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[3],
			{ "aPadding", "octvc1.gsm.trx.status.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_STATUS_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[9];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD;

void  register_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[0],
			{ "u6TrxId_u4band_u1H_u5TSC", "octvc1.gsm.trx.configure.u6trxid_u4band_u1h_u5tsc",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"u6TrxId_u4band_u1H_u5TSC",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[1],
			{ "ARFCN", "octvc1.gsm.trx.configure.arfcn",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"ARFCN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[2],
			{ "BCCH_ARFCN", "octvc1.gsm.trx.configure.bcch_arfcn",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"BCCH_ARFCN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[3],
			{ "HSN", "octvc1.gsm.trx.configure.hsn",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"HSN",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[4],
			{ "MAIO", "octvc1.gsm.trx.configure.maio",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"MAIO",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[5],
			{ "HoppingListLength", "octvc1.gsm.trx.configure.hoppinglistlength",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"HoppingListLength",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[6],
			{ "ausHoppingList", "octvc1.gsm.trx.configure.aushoppinglist",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"ausHoppingList",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[7],
			{ "aPadding", "octvc1.gsm.trx.configure.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[4];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP;

void  register_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[0],
			{ "u6TrxId_u4band_u6Pad", "octvc1.gsm.trx.configure.u6trxid_u4band_u6pad",
			FT_NONE, BASE_NONE, NULL, 0x0,
			"u6TrxId_u4band_u6Pad",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[1],
			{ "usStatus", "octvc1.gsm.trx.configure.usstatus",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usStatus",HFILL }

		},
		{
			&ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[2],
			{ "aPadding", "octvc1.gsm.trx.configure.apadding",
			FT_UINT8,BASE_HEX, NULL, 0x0,
			"aPadding",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_START_ETSI_CMD;

void  register_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD[0],
			{ "usTodo", "octvc1.gsm.test.etsi.start.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_START_ETSI_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_START_ETSI_RSP;

void  register_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP[0],
			{ "usTodo", "octvc1.gsm.test.etsi.start.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_START_ETSI_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_END_ETSI_CMD;

void  register_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD[0],
			{ "usTodo", "octvc1.gsm.test.etsi.end.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_END_ETSI_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_END_ETSI_RSP;

void  register_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP[0],
			{ "usTodo", "octvc1.gsm.test.etsi.end.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_END_ETSI_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_START_FCC_CMD;

void  register_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD[0],
			{ "usTodo", "octvc1.gsm.test.fcc.start.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_START_FCC_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_START_FCC_RSP;

void  register_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP[0],
			{ "usTodo", "octvc1.gsm.test.fcc.start.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_START_FCC_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_END_FCC_CMD;

void  register_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD[0],
			{ "usTodo", "octvc1.gsm.test.fcc.end.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_END_FCC_CMD.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

int ahf_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP[2];
tWS_ENTITY_HANDLE ws_htOCTVC1_GSM_MSG_TEST_END_FCC_RSP;

void  register_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP(void)
{
	static hf_register_info hf[] =
	{
		{
			&ahf_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP[0],
			{ "usTodo", "octvc1.gsm.test.fcc.end.ustodo",
			FT_UINT16,BASE_HEX, NULL, 0x0,
			"usTodo",HFILL }

		},
	};

	static gint* ett[] =
	{
		&ws_htOCTVC1_GSM_MSG_TEST_END_FCC_RSP.ett
	};

	proto_register_field_array( proto_octvc1_ctrl, hf, array_length(hf) );

};

/****************************************************************************
	COMMON dissectors 
 ****************************************************************************/


unsigned int  dissect_tOCTVC1_GSM_tSUBCHANNEL_STATUS(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset, tWS_EXTRA_VALUE *pExtValue )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_tSUBCHANNEL_STATUS)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_tSUBCHANNEL_STATUS (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_tSUBCHANNEL_STATUS));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		bytes = sizeof(tOCTVC1_GSM_tSUBCHANNEL_STATUS);
		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[0], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveUplinkSAPIMapMSW), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveUplinkSAPIMapMSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[1], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveUplinkSAPIMapLSW), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[1], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveUplinkSAPIMapLSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[2], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveDownlinkSAPIMapMSW), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveDownlinkSAPIMapMSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[3], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveDownlinkSAPIMapLSW), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_tSUBCHANNEL_STATUS[3], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tSUBCHANNEL_STATUS, usActiveDownlinkSAPIMapLSW);

	}


	return offset;

};


unsigned int  dissect_tOCTVC1_GSM_tMEASUREMENT_INFO(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset, tWS_EXTRA_VALUE *pExtValue )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_tMEASUREMENT_INFO)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_tMEASUREMENT_INFO (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_tMEASUREMENT_INFO));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		bytes = sizeof(tOCTVC1_GSM_tMEASUREMENT_INFO);
		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_int_format_value(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[0], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, sRSSI), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_int(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, sRSSI);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_int_format_value(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[1], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, sSNR), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_int(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[1], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, sSNR);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_int_format_value(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[2], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, sBurstTiming), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_int(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, sBurstTiming);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[3], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, usBERCount), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[3], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, usBERCount);

		temp_data = tvb_get_ntohs( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[4], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, usBERTOtalBitCOunt), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_tMEASUREMENT_INFO[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_tMEASUREMENT_INFO, usBERTOtalBitCOunt);

	}


	return offset;

};


unsigned int  dissect_tOCTVC1_GSM_TIMESLOT_STATUS(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset, tWS_EXTRA_VALUE *pExtValue )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_TIMESLOT_STATUS)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_TIMESLOT_STATUS (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_TIMESLOT_STATUS));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		bytes = sizeof(tOCTVC1_GSM_TIMESLOT_STATUS);
		temp_data = tvb_get_guint8( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_TIMESLOT_STATUS[0], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_TIMESLOT_STATUS, byChannelType), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_TIMESLOT_STATUS[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_TIMESLOT_STATUS, byChannelType);

		temp_data = tvb_get_guint8( tvb, offset );
		if( pExtValue && (pExtValue->lValue == temp_data ) )
		{
		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_TIMESLOT_STATUS[1], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_TIMESLOT_STATUS, bySubchannelCount), temp_data, "%s (0x%x)",pExtValue->pszValue, temp_data );
		}else
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_TIMESLOT_STATUS[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_TIMESLOT_STATUS, bySubchannelCount);

	}


	return offset;

};

/****************************************************************************
	Event dissectors 
 ****************************************************************************/


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT, byu5Pad_u3TN);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT, usFrameNumberMSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT[3], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT, usFrameNumberLSW);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, byu5SAPI_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, byu5Pad_u3TN);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, usFrameNumberMSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, usFrameNumberLSW);

		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, tMeasurementInfo), "tMeasurementInfo:tOCTVC1_GSM_tMEASUREMENT_INFO");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_GSM_tMEASUREMENT_INFO( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[7], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, usDataFrameLength);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT, ausDataFrameContents), "ausDataFrameContents");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<234; i++ )
			{
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT[8], tvb, offset,
			2, temp_data, "[%d]: 0x%04x", i, temp_data );
		}
				offset+=2;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT, byu2Pad_u6TRXId);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT, byu3TN_u5SAPI);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT, byPad);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT, usFrameNumberMSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT, usFrameNumberLSW);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, byuu3TN_u5SAPI);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, byBurstType);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, usFrameNumberMSW);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, usFrameNumberLSW);

		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, tMeasurementInfo), "tMeasurementInfo:tOCTVC1_GSM_tMEASUREMENT_INFO");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_GSM_tMEASUREMENT_INFO( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[7], tvb, offset,
			2, temp_data);
		if( ( (unsigned int)temp_data < 0) || ( (unsigned int)temp_data > cOCTVC1_GSM_cSDR_RACH_IND_MAX_MESSAGE_LENGTH_WORDS ) )
		{
			proto_item_set_expert_flags(ti, PI_MALFORMED, PI_ERROR);
			proto_item_append_text(ti," [Out of range - (0..cOCTVC1_GSM_cSDR_RACH_IND_MAX_MESSAGE_LENGTH_WORDS)]" );
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, usMessageLength);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT, ausMessageContents), "ausMessageContents");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<16; i++ )
			{
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT[8], tvb, offset,
			2, temp_data, "[%d]: 0x%04x", i, temp_data );
		}
				offset+=2;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_ERROR_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_ERROR_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_ERROR_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_ERROR_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_ERROR_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_ERROR_EVT, ulErrorCode);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT, ulMessageCode);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT, ulSeverityLevel);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, ulCoreId);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, ulFrameIndex);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[3], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, ulSlotIndex);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, ulCheckPointType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[5], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, ulProcessUnitType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[6], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, ulState);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT, aulReserved), "aulReserved");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<3; i++ )
			{
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT[7], tvb, offset,
			4, temp_data, "[%d]: 0x%08x", i, temp_data );
		}
				offset+=4;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_TRACING_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_TRACING_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, ulCoreId);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, ulTraceType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_boolean(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[3], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, ulLastTracePacket), temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, ulLastTracePacket);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, ulTraceIndex);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[5], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, ulPayloadSizeBytes);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_TRACING_EVT, abyUnparsedPayload), "abyUnparsedPayload");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<512; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT[6], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT, ulErrorCode);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT, ulMessageCode);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT, ulSeverityLevel);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, ulCoreId);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, ulFrameIndex);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[3], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, ulSlotIndex);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, ulCheckPointType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[5], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, ulProcessUnitType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[6], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, ulState);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT, aulReserved), "aulReserved");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<3; i++ )
			{
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT[7], tvb, offset,
			4, temp_data, "[%d]: 0x%08x", i, temp_data );
		}
				offset+=4;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT, ulCoreId);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT, ulTraceType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[3], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT, ulPayloadSizeBytes);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT, abyUnparsedPayload), "abyUnparsedPayload");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<512; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT[4], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT)-sizeof(tOCTVC1_EVENT_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT)-sizeof(tOCTVC1_EVENT_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT, usTodo);

	}


	return 0;

};

/****************************************************************************
	CMD/RSP dissectors 
 ****************************************************************************/


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<488; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD[0], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP, szHardwareInfo), "szHardwareInfo");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<253; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP[0], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<210; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP[1], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[0], tvb, offset,
			4,"ulEventMask: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_EVT_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_EVT_MASK[i].value && 
					( vals_tOCTVC1_GSM_EVT_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_EVT_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,4,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_EVT_MASK[i].value, 0xFFFFFFFF, (4*8),
				VALS(vals_tOCTVC1_GSM_EVT_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD, ulEventMask);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD, ulUserEventId);

		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD, hEventDestObj), "hEventDestObj:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[3], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD, ulEventDestObjPort);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD, ulEventDestObjFifoId);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[0], tvb, offset,
			4,"ulEventMask: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_EVT_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_EVT_MASK[i].value && 
					( vals_tOCTVC1_GSM_EVT_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_EVT_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,4,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_EVT_MASK[i].value, 0xFFFFFFFF, (4*8),
				VALS(vals_tOCTVC1_GSM_EVT_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP, ulEventMask);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP, ulUserEventId);

		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP, hEventDestObj), "hEventDestObj:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[3], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP, ulEventDestObjPort);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP, ulEventDestObjFifoId);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_MODULE_INFO_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_MODULE_INFO_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_MODULE_INFO_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_MODULE_INFO_RSP[0], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_MODULE_INFO_RSP, ulDeviceType);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		if( temp_data == cOCTVC1_DO_NOT_MODIFY)
		{		ti = proto_tree_add_uint_format_value(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[1], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD, ulUserEventId),temp_data, "cOCTVC1_DO_NOT_MODIFY (0x%08x)",temp_data);
		}else {
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[1], tvb, offset,
			4, temp_data);
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD, ulUserEventId);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[2], tvb, offset,
			4,"ulEventMask: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_EVT_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_EVT_MASK[i].value && 
					( vals_tOCTVC1_GSM_EVT_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_EVT_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,4,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_EVT_MASK[i].value, 0xFFFFFFFF, (4*8),
				VALS(vals_tOCTVC1_GSM_EVT_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD, ulEventMask);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD[3], tvb, offset,
			4,"ulDebugFwdEventMask: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_EVT_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_EVT_MASK[i].value && 
					( vals_tOCTVC1_GSM_EVT_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_EVT_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,4,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_EVT_MASK[i].value, 0xFFFFFFFF, (4*8),
				VALS(vals_tOCTVC1_GSM_EVT_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD, ulDebugFwdEventMask);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD, hProcessUnit), "hProcessUnit:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[0], tvb, offset,
			4,"ulEventMask: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_EVT_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_EVT_MASK[i].value && 
					( vals_tOCTVC1_GSM_EVT_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_EVT_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,4,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_EVT_MASK[i].value, 0xFFFFFFFF, (4*8),
				VALS(vals_tOCTVC1_GSM_EVT_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP, ulEventMask);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP, ulUserEventId);

		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP, hEventDestObj), "hEventDestObj:tOCTVC1_HANDLE");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_HANDLE( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[3], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP, ulEventDestObjPort);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP, ulEventDestObjFifoId);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD, ObjectCursor), "ObjectCursor:tOCTVC1_CURSOR_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_CURSOR_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP, ObjectCursor), "ObjectCursor:tOCTVC1_CURSOR_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_CURSOR_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP, ObjectList), "ObjectList:tOCTVC1_LIST_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_LIST_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD, ObjectGet), "ObjectGet:tOCTVC1_CURSOR_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_CURSOR_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP, ObjectGet), "ObjectGet:tOCTVC1_CURSOR_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_CURSOR_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP, ulProcessType);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[2], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP, ulInstance);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_boolean(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[3], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP, ulMasterCore), temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP, ulMasterCore);

		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP[4], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP, ulCoreId);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD, ObjectGet), "ObjectGet:tOCTVC1_CURSOR_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_CURSOR_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_boolean(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD[1], tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD, ulResetStatsFlag), temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD, ulResetStatsFlag);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP, ObjectGet), "ObjectGet:tOCTVC1_CURSOR_HANDLE_GET");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_CURSOR_HANDLE_GET( tvb, pinfo, sub_tree2, offset, NULL );
		}
		temp_data = tvb_get_ntohl( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP[1], tvb, offset,
			4, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP, ulLastFrameIndex);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, byu3TN_u5SAPI);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, byPad);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, usFrameNumberMsb);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, usFrameNumberLsb);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<480; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD[6], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, byU2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, byU3TN_u5SAPI);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, byPad);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, usFrameNumberMSB);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, usFrameNumberLSB);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[6], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, usDataLength);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD, ausDataContents), "ausDataContents");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<478; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD[7], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, byu2Pad_u3TN_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, byuCipherId);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, usKC0);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, usKC1);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[6], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, usKC2);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD[7], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD, usKC3);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP, byu2Pad_u3TN_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP, byPad);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<458; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP[5], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD, byu2Pad_u6TrxId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD, byu5Pad_u3TimeslotNumber);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD, byChannelType);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD, byPayloadType);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<484; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD[4], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP, byu5Pad_u3TN);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<460; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP[3], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD, byu2Pad_u6TrxId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD, byu5Pad_u3TimeslotNumber);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<476; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD[2], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP, byu5Pad_u3TN);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<460; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP[3], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<462; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD[0], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<476; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP[1], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byu2Pad_u3TN_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byu3Pad_u5SAPI);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[4], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byTimingAdvance);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[5], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byPad);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[6], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byBSIC);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[7], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byu1CMIPhase_u7InitRate);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[8], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byu4Rate1_u4Rate2);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[9], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, byu4Rate3_u4Rate4);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<476; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD[10], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP, byu2Pad_u3TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP, byu2Pad_u3TN_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP, byu3Pad_u5SAPI);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<458; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP[5], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD, byu2Pad_u3TN_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD, byu3Pad_u5SAPI);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP, byu2Pad_u3TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP, byu2Pad_u3TN_u3Dir);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP, bySubchannelNum);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP, byu3Pad_u5SAPI);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[4], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<458; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP[5], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD, usu2Pad_u6TRXId_u5Pad_u3TN);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP, usu2Pad_u6TRXId_u5Pad_u3TN);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP, byChannelType);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[2], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP, bySubchannelCount);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP, atSubchannnelStatus), "atSubchannnelStatus:tOCTVC1_GSM_tSUBCHANNEL_STATUS");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<16; i++ )
			{
		{
			proto_tree*	sub_tree2;
			ti = proto_tree_add_text(sub_tree, tvb, offset,
				sizeof(tOCTVC1_GSM_tSUBCHANNEL_STATUS), "[%d]:", i);
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_GSM_tSUBCHANNEL_STATUS( tvb, pinfo, sub_tree2, offset, NULL );
		}
			}
		}
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<332; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP[4], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD, byu5Pad_u3TN);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP, byu5Pad_u3TN);

		ti = proto_tree_add_text(field_tree, tvb, offset, 
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP, tMeasurementInfo), "tMeasurementInfo:tOCTVC1_GSM_tMEASUREMENT_INFO");
		{
			proto_tree*	sub_tree2;
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_GSM_tMEASUREMENT_INFO( tvb, pinfo, sub_tree2, offset, NULL );
		}
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<454; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP[3], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_RESET_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_RESET_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_RESET_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_RESET_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_RESET_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_RESET_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_RESET_CMD, usu2Pad_u6TRXId_u8Pad);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_RESET_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<486; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_RESET_CMD[1], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_RESET_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_RESET_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_RESET_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_RESET_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_RESET_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_RESET_RSP, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_RESET_RSP, byPad);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_RESET_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_RESET_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<460; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_RESET_RSP[3], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_STATUS_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_CMD, usu2Pad_u6TRXId_u8Pad);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_STATUS_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_STATUS_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_STATUS_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[0], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_RSP, byu2Pad_u6TRXId);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[1], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_RSP, byPad);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_RSP, atStatus), "atStatus:tOCTVC1_GSM_TIMESLOT_STATUS");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<8; i++ )
			{
		{
			proto_tree*	sub_tree2;
			ti = proto_tree_add_text(sub_tree, tvb, offset,
				sizeof(tOCTVC1_GSM_TIMESLOT_STATUS), "[%d]:", i);
			sub_tree2 = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			offset = dissect_tOCTVC1_GSM_TIMESLOT_STATUS( tvb, pinfo, sub_tree2, offset, NULL );
		}
			}
		}
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_STATUS_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<446; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_STATUS_RSP[3], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[0], tvb, offset,
			2,"u6TrxId_u4band_u1H_u5TSC: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value && 
					( vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,2,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value, 0xFFFFFFFF, (2*8),
				VALS(vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, u6TrxId_u4band_u1H_u5TSC);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[1], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, ARFCN);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[2], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, BCCH_ARFCN);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[3], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, HSN);

		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[4], tvb, offset,
			1, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, MAIO);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[5], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, HoppingListLength);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, ausHoppingList), "ausHoppingList");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<64; i++ )
			{
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[6], tvb, offset,
			2, temp_data, "[%d]: 0x%04x", i, temp_data );
		}
				offset+=2;
			}
		}
		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<350; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD[7], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_none_format(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[0], tvb, offset,
			2,"u6TrxId_u4band_u6Pad: (0x%08x)", temp_data);
		if(temp_data)
		{
			int i;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i< mWS_COUNTOF(vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK); i++ )
			{
				if( ( vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value && 
					( vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value & temp_data ) == 
					 vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value))
					proto_tree_add_text(sub_tree, tvb, offset,2,"%s",
					decode_enumerated_bitfield(vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK[i].value, 0xFFFFFFFF, (2*8),
				VALS(vals_tOCTVC1_GSM_TRX_BAND_HOPPING_TSC_MASK),"%s"));
			}
		}
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP, u6TrxId_u4band_u6Pad);

		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[1], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP, usStatus);

		ti = proto_tree_add_text(field_tree, tvb, offset,
			mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP, aPadding), "aPadding");
		{
			int i, ofs=offset;
			proto_tree*	sub_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
			for( i=0; i<460; i++ )
			{
		temp_data = tvb_get_guint8( tvb, offset );
		{
		ti = proto_tree_add_uint_format(sub_tree, ahf_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP[2], tvb, offset,
			1, temp_data, "[%d]: 0x%02x", i, temp_data );
		}
				offset+=1;
			}
		}
	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_START_FCC_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_FCC_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_START_FCC_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_FCC_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_START_FCC_CMD, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_START_FCC_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_FCC_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_START_FCC_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_START_FCC_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_START_FCC_RSP, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_END_FCC_CMD)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_FCC_CMD (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_END_FCC_CMD)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_FCC_CMD (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_END_FCC_CMD, usTodo);

	}


	return 0;

};


unsigned int  dissect_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, unsigned int offset )
{
	proto_tree *field_tree = tree;
	unsigned int offset_0 = offset;
	gint bytes = tvb_length_remaining(tvb, offset);
	if (bytes < (gint)(sizeof(tOCTVC1_GSM_MSG_TEST_END_FCC_RSP)-sizeof(tOCTVC1_MSG_HEADER)))
	{
		proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_FCC_RSP (%d byte%s) - Malformated packet...expected(%ld)",
			bytes, plurality(bytes, "", "s"),
			sizeof(tOCTVC1_GSM_MSG_TEST_END_FCC_RSP)-sizeof(tOCTVC1_MSG_HEADER));
		return 1;
	}
	else
	{
		int  temp_data = 0;
		proto_item *ti;
		ti = proto_tree_add_text(tree, tvb, offset, bytes,
			"tOCTVC1_GSM_MSG_TEST_END_FCC_RSP (%d byte%s)", bytes, plurality(bytes, "", "s"));

		field_tree = proto_item_add_subtree(ti, ett_octvc1_msg_type);
		temp_data = tvb_get_ntohs( tvb, offset );
		{
		ti = proto_tree_add_uint(field_tree, ahf_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP[0], tvb, offset,
			2, temp_data);
		}
		offset += mWS_FIELDSIZE(tOCTVC1_GSM_MSG_TEST_END_FCC_RSP, usTodo);

	}


	return 0;

};
/****************************************************************************
	MODULE REGISTERED EXPORTED FUNCTION
 ****************************************************************************/

void ws_register_OCTVC1_GSM(void)
{
	/****************************************************************************
		Register Common struct
	****************************************************************************/
	register_tOCTVC1_GSM_tSUBCHANNEL_STATUS(); 
	register_tOCTVC1_GSM_tMEASUREMENT_INFO(); 
	register_tOCTVC1_GSM_TIMESLOT_STATUS(); 

	/****************************************************************************
		CMD/RSP Registered 
	****************************************************************************/
	register_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD(); 
	register_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP(); 
	register_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD(); 
	register_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP(); 
	register_tOCTVC1_GSM_MSG_MODULE_INFO_RSP(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD(); 
	register_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP(); 
	register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD(); 
	register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP(); 
	register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD(); 
	register_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP(); 
	register_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD(); 
	register_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP(); 
	register_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD(); 
	register_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP(); 
	register_tOCTVC1_GSM_MSG_TRX_RESET_CMD(); 
	register_tOCTVC1_GSM_MSG_TRX_RESET_RSP(); 
	register_tOCTVC1_GSM_MSG_TRX_STATUS_CMD(); 
	register_tOCTVC1_GSM_MSG_TRX_STATUS_RSP(); 
	register_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD(); 
	register_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP(); 
	register_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD(); 
	register_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP(); 
	register_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD(); 
	register_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP(); 
	register_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD(); 
	register_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP(); 
	register_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD(); 
	register_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP(); 

	/****************************************************************************
		Event Registered 
	****************************************************************************/
	register_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT(); 
	register_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT(); 
	register_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT(); 
	register_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT(); 

}

/****************************************************************************
	MODULE DISSECTOR FUNCTIONS
 ****************************************************************************/
int ws_dissect_OCTVC1_GSM_CMD( guint32 CID, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
{
	if( tree )
	{
		switch( CID ) {
			case cOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CID: return dissect_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CID: return dissect_tOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_INFO_EVT_CID: return 0; break;
			case cOCTVC1_GSM_MSG_MODULE_INFO_CID: return 0; break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CID: return dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CID: return dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CID: return dissect_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CID: return dissect_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_RESET_CID: return dissect_tOCTVC1_GSM_MSG_TRX_RESET_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_STATUS_CID: return dissect_tOCTVC1_GSM_MSG_TRX_STATUS_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_CONFIGURE_CID: return dissect_tOCTVC1_GSM_MSG_TRX_CONFIGURE_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_START_ETSI_CID: return dissect_tOCTVC1_GSM_MSG_TEST_START_ETSI_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_END_ETSI_CID: return dissect_tOCTVC1_GSM_MSG_TEST_END_ETSI_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_START_FCC_CID: return dissect_tOCTVC1_GSM_MSG_TEST_START_FCC_CMD( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_END_FCC_CID: return dissect_tOCTVC1_GSM_MSG_TEST_END_FCC_CMD( tvb, pinfo, tree, 0 ); break;
			default: return 1;
		}
	}
	return 0;

}
int ws_dissect_OCTVC1_GSM_RSP( guint32 CID, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
{
	if( tree )
	{
		switch( CID ) {
			case cOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_CID: return dissect_tOCTVC1_GSM_MSG_MODULE_INFO_HARDWARE_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_MODIFY_EVT_CID: return 0; break;
			case cOCTVC1_GSM_MSG_MODULE_INFO_EVT_CID: return dissect_tOCTVC1_GSM_MSG_MODULE_INFO_EVT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_INFO_CID: return dissect_tOCTVC1_GSM_MSG_MODULE_INFO_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_MODIFY_EVT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_EVT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_LIST_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_INFO_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_CID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_STATS_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_EMPTY_FRAME_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_REQUEST_DATA_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONFIGURE_CIPHERING_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_CONNECT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_DISCONNECT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_CID: return dissect_tOCTVC1_GSM_MSG_PHYSICAL_CHANNEL_RESET_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_CID: return dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_ACTIVATE_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_CID: return dissect_tOCTVC1_GSM_MSG_LOGICAL_CHANNEL_DEACTIVATE_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_CID: return dissect_tOCTVC1_GSM_MSG_TRX_STATUS_TIMESLOT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_CID: return dissect_tOCTVC1_GSM_MSG_TRX_REQUEST_TIMESLOT_MEASUREMENT_REPORT_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_RESET_CID: return dissect_tOCTVC1_GSM_MSG_TRX_RESET_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_STATUS_CID: return dissect_tOCTVC1_GSM_MSG_TRX_STATUS_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TRX_CONFIGURE_CID: return dissect_tOCTVC1_GSM_MSG_TRX_CONFIGURE_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_START_ETSI_CID: return dissect_tOCTVC1_GSM_MSG_TEST_START_ETSI_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_END_ETSI_CID: return dissect_tOCTVC1_GSM_MSG_TEST_END_ETSI_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_START_FCC_CID: return dissect_tOCTVC1_GSM_MSG_TEST_START_FCC_RSP( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_END_FCC_CID: return dissect_tOCTVC1_GSM_MSG_TEST_END_FCC_RSP( tvb, pinfo, tree, 0 ); break;
			default: return 1;
		}
	}
	return 0;

}
int ws_dissect_OCTVC1_GSM_EVT( guint32 CID, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
{
	if( tree )
	{
		switch( CID ) {
			case cOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_TIME_INDICATION_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_DATA_INDICATION_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_TRX_RADIO_READY_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_READY_TO_SEND_INDICATION_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_RACH_INDICATION_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_ERROR_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_ERROR_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_MESSAGE_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_MESSAGE_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_CHECKPOINT_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_MODULE_TRACING_EID: return dissect_tOCTVC1_GSM_MSG_MODULE_TRACING_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_ERROR_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_MESSAGE_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_CHECKPOINT_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EID: return dissect_tOCTVC1_GSM_MSG_PROCESS_UNIT_TRACING_EVT( tvb, pinfo, tree, 0 ); break;
			case cOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EID: return dissect_tOCTVC1_GSM_MSG_TEST_ETSI_TEST_REPORT_EVT( tvb, pinfo, tree, 0 ); break;
			default: return 1;
		}
	}
	return 0;

}

/****************************************************************************
	MODULE DISSECTOR EXPORTED FUNCTION
 ****************************************************************************/

int ws_dissect_OCTVC1_GSM( guint8 message_type, guint32 CID, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
{
	if (message_type == cOCTVC1_MSG_TYPE_RESPONSE)
		return ws_dissect_OCTVC1_GSM_RSP( CID, tvb, pinfo, tree);
	if (message_type == cOCTVC1_MSG_TYPE_COMMAND)
		return ws_dissect_OCTVC1_GSM_CMD( CID, tvb, pinfo, tree);
	if (message_type == cOCTVC1_MSG_TYPE_NOTIFICATION )
		return ws_dissect_OCTVC1_GSM_EVT( CID, tvb, pinfo, tree);
	else
		return 1;

}

